/**
 * 
 */
package kcg.faics.board.service.impl;

import java.util.List;

import kcg.faics.board.vo.BoardFileVO;

import org.springframework.stereotype.Repository;

import egovframework.rte.psl.dataaccess.EgovAbstractMapper;

/**
 * 게시판에 관한 인터페이스클래스를 정의한다.
 * @author 임새미
 * @since 2016. 9. 22.
 * @version 1.0
 * @see 
 * <pre>
 *     수정일               수정자            수정내용
 *  ----------  --------  -------------------------
 *  2016.09.22    임새미           최초 생성
 * </pre>
 */
@Repository("boardFileMapper")
public class BoardFileMapper extends EgovAbstractMapper {
	
	/**
	 * 게시물의 첨부파일을 DB에 추가한다.
	 * 
	 * @param boardFileVO 업로드 파일 정보 객체
	 * @return 성공 - 1, 실패 - 0
	 * @exception Exception 기본 예외 처리
	 */
	public int insertFile(final BoardFileVO boardFileVO) throws Exception {
		return insert("BoardFile.insertBoardFile", boardFileVO);
	}
	
	/**
	 * 선택한 게시물의 파일 리스트를 반환한다.
	 * 
	 * @param boardFileVO 게시판 아이디
	 * @return 선택한 게시물의 덧글 리스트
	 * @throws Exception 기본 예외 처리
	 */
	public List<BoardFileVO> selectFiles(final BoardFileVO boardFileVO) throws Exception {
		return selectList("BoardFile.selectBoardFiles", boardFileVO);
	}

	/**
	 * 선택한 파일정보를 반환한다.
	 * 
	 * @param boardFileVO 덧글 아이디
	 * @return 선택한 덧글의 상세 내용
	 * @throws Exception 기본 예외 처리
	 */
	public BoardFileVO selectFile(final BoardFileVO boardFileVO)  throws Exception {
		return selectOne("BoardFile.selectBoardFile", boardFileVO);
	}

	/**
	 * DB에서 파일정보를 삭제한다.
	 * 
	 * @param bfSeq 덧글 아이디
	 * @return 성공 - 1, 실패 - 0
	 * @throws Exception 기본 예외 처리
	 */
	public int deleteFile(final BoardFileVO boardFileVO) throws Exception {
		return delete("BoardFile.deleteBoardFile", boardFileVO);
	}
	
	
}
